<?php

namespace Litepie\Calendar\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litepie\Calendar\Interfaces\CalendarRepositoryInterface;
use Litepie\Calendar\Repositories\Eloquent\Filters\CalendarPublicFilter;
use Litepie\Calendar\Repositories\Eloquent\Presenters\CalendarListPresenter;

class CalendarPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        CalendarRepositoryInterface $calendar
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litepie.calendar.modules'), 'calendar', guard_url('calendar'));
        $this->repository = $calendar;
    }

    /**
     * Show calendar's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(CalendarPublicFilter::class)
            ->setPresenter(CalendarListPresenter::class)
            ->select('calendars.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('calendar::calendar.names'))
            ->view('calendar::public.calendar.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show calendar.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('calendar::calendar.name'))
            ->view('calendar::public.calendar.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
