<?php

namespace Litepie\Calendar\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litepie\Calendar\Models\Calendar;

class CalendarPolicy
{

    /**
     * Determine if the given user can view the calendar.
     *
     * @param UserPolicyInterface $authUser
     * @param Calendar $calendar
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Calendar $calendar)
    {
        if ($authUser->canDo('calendar.calendar.view') && $authUser->isAdmin()) {
            return true;
        }

        return $calendar->user_id == user_id() && $calendar->user_type == user_type();
    }

    /**
     * Determine if the given user can create a calendar.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('calendar.calendar.create');
    }

    /**
     * Determine if the given user can update the given calendar.
     *
     * @param UserPolicyInterface $authUser
     * @param Calendar $calendar
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Calendar $calendar)
    {
        if ($authUser->canDo('calendar.calendar.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $calendar->user_id == user_id() && $calendar->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given calendar.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Calendar $calendar)
    {
        return $calendar->user_id == user_id() && $calendar->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given calendar.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Calendar $calendar)
    {
        if ($authUser->canDo('calendar.calendar.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given calendar.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Calendar $calendar)
    {
        if ($authUser->canDo('calendar.calendar.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
